within OpenWPL.Tests;

model Pipe_test_v10
  extends OpenWPL.Icons.Pipe;
  //inner declarations (global variables and constants)
  inner Modelica.Fluid.System system(
    T_ambient = 287.15,allowFlowReversal = false, 
    energyDynamics = Modelica.Fluid.Types.Dynamics.FixedInitial)     
    annotation(
  Placement(transformation(extent={{60,60},{80,80}})));
  inner OpenWPL.MOC moc(N = 4, T = 150)  annotation(
    Placement(visible = true, transformation(origin = {48, 70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  //medium declarations
  replaceable package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater 
    constrainedby Modelica.Media.Interfaces.PartialMedium "Medium in the component";
  //upper tank
  Modelica.Fluid.Vessels.OpenTank Source(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater,
    crossArea=1,
    height= 11,
    level_start= 10,
    nPorts= 1,
    portsData={Modelica.Fluid.Vessels.BaseClasses.VesselPortsData(diameter=0.1)})  
    annotation(
    Placement(visible = true, transformation(origin = {-62, 4}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
  //pipe between tanks
  OpenWPL.Components.Pipe_MSL_v8 pipe(
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater, allowFlowReversal = false,
    diameter_in = 1, diameter_out = 1, friction = true,
    height_ab=-1,
    length= 100)
    annotation(
    Placement(visible = true, transformation(origin = {-8, -16}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  //lower tank
  Modelica.Fluid.Vessels.OpenTank Sink(
    
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater,crossArea=1,
    height=1.1,
    level_start=1.0e-10,
    nPorts= 1,
    portsData={Modelica.Fluid.Vessels.BaseClasses.VesselPortsData(diameter=0.1, height=0.5)})  
    annotation(
    Placement(visible = true, transformation(origin = {46, 4}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
equation
  connect(Source.ports[1], pipe.port_a) annotation(
    Line(points = {{-62, -16}, {-18, -16}, {-18, -16}, {-18, -16}}, color = {0, 127, 255}));
  connect(pipe.port_b, Sink.ports[1]) annotation(
    Line(points = {{2, -16}, {40, -16}, {40, -16}, {46, -16}}, color = {0, 127, 255}));
protected
  annotation(
    __OpenModelica_commandLineOptions = "--matchingAlgorithm=PFPlusExt --indexReductionMethod=dynamicStateSelection -d=initialization,NLSanalyticJacobian",
    Diagram,
  experiment(StartTime = 0, StopTime = 1, Tolerance = 1e-6, Interval = 0.002));

end Pipe_test_v10;
